@@ -1,7 +1,5 @@
-#include <iostream>
+#include <algorithm>
 #include <string>
-using namespace std;
-
 #include <R.h>
 #include <Rinternals.h>
 #include <R_ext/Linpack.h>
@@ -48,10 +46,10 @@ extern "C" {
     
     double *coordsD = REAL(coordsD_r);
 
-    string covModel = CHAR(STRING_ELT(covModel_r,0));
+    std::string covModel = CHAR(STRING_ELT(covModel_r,0));
 
     //priors
-    string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
+    std::string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
     double *betaMu = NULL;
     double *betaC = NULL;
     
@@ -473,9 +471,9 @@ extern "C" {
       	  REAL(tuning_r)[b*nParams+j] = tuning[j];
 	  
       	  if(accept[j]/batchLength > acceptRate){
-      	    tuning[j] += min(0.01, 1.0/sqrt(static_cast<double>(b)));
+      	    tuning[j] += std::min(0.01, 1.0/sqrt(static_cast<double>(b)));
       	  }else{
-      	    tuning[j] -= min(0.01, 1.0/sqrt(static_cast<double>(b)));
+      	    tuning[j] -= std::min(0.01, 1.0/sqrt(static_cast<double>(b)));
       	  }
       	  accept[j] = 0.0;
       	}
