@@ -1,7 +1,4 @@
-#include <iostream>
 #include <string>
-using namespace std;
-
 #include <R.h>
 #include <Rinternals.h>
 #include <R_ext/Linpack.h>
@@ -60,7 +57,7 @@ extern "C" {
     double *obsPredD = REAL(obsPredD_r);
     
     //priors
-    string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
+    std::string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
     double *betaMu = NULL;
     double *betaC = NULL;
     
@@ -72,7 +69,7 @@ extern "C" {
       F77_NAME(dcopy)(&pp, REAL(VECTOR_ELT(betaNorm_r, 1)), &incOne, betaC, &incOne);
     }
     
-    string covModel = CHAR(STRING_ELT(covModel_r,0));
+    std::string covModel = CHAR(STRING_ELT(covModel_r,0));
     bool nugget = static_cast<bool>(INTEGER(nugget_r)[0]);
     int verbose = INTEGER(verbose_r)[0];
     int nReport = INTEGER(nReport_r)[0];
