@@ -1,10 +1,8 @@
-#include <iostream>
+#include <algorithm>
 #include <string>
 #ifdef _OPENMP
 #include <omp.h>
 #endif
-//using namespace std;
-
 #include <R.h>
 #include <Rinternals.h>
 #include <R_ext/Linpack.h>
@@ -53,15 +51,15 @@ extern "C" {
 
     double *coordsD = REAL(coordsD_r);
 
-    string family = CHAR(STRING_ELT(family_r,0));
+    std::string family = CHAR(STRING_ELT(family_r,0));
 
     int *weights = INTEGER(weights_r);
 
     //covariance model
-    string covModel = CHAR(STRING_ELT(covModel_r,0));
+    std::string covModel = CHAR(STRING_ELT(covModel_r,0));
 
     //priors and starting
-    string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
+    std::string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
 
     double *betaMu = NULL;
     double *betaSd = NULL;
@@ -506,9 +504,9 @@ extern "C" {
 	REAL(tuning_r)[b*nParams+j] = spTuning[j];
 	
 	if(accept[j]/batchLength > acceptRate){
-	  spTuning[j] += min(0.01, 1.0/sqrt(static_cast<double>(b)));
+	  spTuning[j] += std::min(0.01, 1.0/sqrt(static_cast<double>(b)));
 	}else{
-	  spTuning[j] -= min(0.01, 1.0/sqrt(static_cast<double>(b)));
+	  spTuning[j] -= std::min(0.01, 1.0/sqrt(static_cast<double>(b)));
 	}
 	accept[j] = 0.0;
       }
@@ -518,9 +516,9 @@ extern "C" {
 	REAL(tuning_w_r)[b*nm+j] = wTuning[j];
 	
 	if(accept_w[j]/batchLength > acceptRate){
-	  wTuning[j] += min(0.01, 1.0/sqrt(static_cast<double>(b)));
+	  wTuning[j] += std::min(0.01, 1.0/sqrt(static_cast<double>(b)));
 	}else{
-	  wTuning[j] -= min(0.01, 1.0/sqrt(static_cast<double>(b)));
+	  wTuning[j] -= std::min(0.01, 1.0/sqrt(static_cast<double>(b)));
 	}
 	accept_w[j] = 0.0;
       }
