@@ -1,10 +1,7 @@
-#include <iostream>
 #include <string>
 #ifdef _OPENMP
 #include <omp.h>
 #endif
-//using namespace std;
-
 #include <R.h>
 #include <Rinternals.h>
 #include <R_ext/Linpack.h>
@@ -48,19 +45,19 @@ extern "C" {
     int m = INTEGER(m_r)[0];
     int nLTr = m*(m-1)/2+m;
 
-    string family = CHAR(STRING_ELT(family_r,0));
+    std::string family = CHAR(STRING_ELT(family_r,0));
 
     int *weights = INTEGER(weights_r);
 
     //covariance model
-    string covModel = CHAR(STRING_ELT(covModel_r,0));
+    std::string covModel = CHAR(STRING_ELT(covModel_r,0));
 
     int q = INTEGER(q_r)[0];
     double *knotsD = REAL(knotsD_r);
     double *knotsCoordsD = REAL(knotsCoordsD_r);
 
     //priors and starting
-    string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
+    std::string betaPrior = CHAR(STRING_ELT(betaPrior_r,0));
 
     double *betaMu = NULL;
     double *betaSd = NULL;
